==> conf-ini-g-2023.1.tar.gz: conf-ini-g-2023.1/conf_ini_g/light/xlsx.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from openpyxl import load_workbook as WorkbookFromPath

from conf_ini_g.light.config import config_as_dict_h
from conf_ini_g.standard.path_extension import any_path_h
from conf_ini_g.standard.str_extension import ValueFromStr


def NewConfigFromPath(path: any_path_h, /) -> config_as_dict_h:
    """"""
    output = {}

    workbook = WorkbookFromPath(filename=path)
    for sheet_name, sheet in workbook.items():
        contents = {}
        for row in tuple(sheet.rows):
            contents[row[0].value] = ValueFromStr(row[1].value)

        output[sheet_name] = contents

    return output

==> conf-ini-g-2023.4.tar.gz: conf-ini-g-2023.4/conf_ini_g/light/xlsx.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from openpyxl import load_workbook as WorkbookFromPath

from conf_ini_g.light.config import config_as_dict_h
from conf_ini_g.standard.path_extension import any_path_h
from conf_ini_g.standard.str_extension import ConvertedValue


def NewConfigFromPath(path: any_path_h, /) -> config_as_dict_h:
    """"""
    output = {}

    workbook = WorkbookFromPath(filename=path)
    for name in workbook.sheetnames:
        sheet = workbook[name]
        contents = {}
        for row in tuple(sheet.rows):
            contents[row[0].value] = ConvertedValue(row[1].value)

        output[name] = contents

    return output
